@@ -1,23 +1,28 @@
-from ..metaClasses.NestProvider import NestProvider
+from bottlenest.core.NestProvider import NestProvider
 
 
 def Injectable():
     def wrapper(originalClass):
-        return NestInjectable(
-            originalClass=originalClass,
-        )
+        def inner(moduleContext):
+            return NestInjectable(
+                originalClass=originalClass,
+                moduleContext=moduleContext,
+            )
+        return inner
     return wrapper
 
 
 class NestInjectable(NestProvider):
     __name__ = 'NestInjectable'
 
-    def __init__(self, originalClass):
-        # self.__name__ = originalClass.__name__
-        self.cls = originalClass
+    def __init__(self, originalClass, moduleContext):
         self.providerName = originalClass.__name__
         self.originalClass = originalClass
-        self.classInstance = None
+        self.providerClass = originalClass
+        # self.classInstance = None
+        # TODO: moduleContext should be optional here
+        self.classInstance = self.originalClass(moduleContext)
+        self.provider = self.classInstance
         # self.dependencies = []
 
     def getName(self):
@@ -45,3 +50,6 @@ class NestInjectable(NestProvider):
 
     def __str__(self):
         return f"{self.providerName}()"
+
+    def listen(self, pool):
+        pass
