@@ -1,22 +1,24 @@
 from .factories.WebsocketsFactory import WebsocketsFactory
+from bottlenest.core.NestTransport import NestTransport
 
 
-class WebsocketsTransport:
+class WebsocketsTransport(NestTransport):
+    __sioids = 0
+
     # called by user, passing any options
     def __init__(self):
         pass
 
-    def setupTransport(self, appContext, moduleContext):
-        print("================== setup WebsocketsTransport")
-        # self.appContext = appContext
-        # self.module = appContext.module
-        # self.logger = appContext.logger
-        WebsocketsFactory.setAppContext(appContext)
-        pass
+    def getTransportKey(self):
+        WebsocketsTransport.__sioids += 1
+        return 'WebsocketsTransport', f"sio-{WebsocketsTransport.__sioids}"
 
-    def listen(self, callback):
-        WebsocketsFactory.listen()
-        callback()
+    def setupTransport(self, appContext, moduleContext):
+        self.appContext = appContext
+        self.moduleContext = moduleContext
+
+    def listen(self, pool):
+        pass
 
     # def listen(self, callback):
     #     # TODO: review this port to allow multiple ports
